@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.8.8;
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 use Log::Log4perl ':easy';
 use Moo::Role;
@@ -58,15 +58,15 @@ App::SFDC::Role::Logging
 
 =head1 VERSION
 
-version 0.13
+version 0.15
 
 =head1 AUTHOR
 
-Alexander Brett <alexander.brett@sophos.com>
+Alexander Brett <alexander.brett@sophos.com> L<http://alexander-brett.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Sophos Limited.
+This software is Copyright (c) 2015 by Sophos Limited L<https://www.sophos.com/>.
 
 This is free software, licensed under:
 
